@@ -9,7 +9,9 @@ use Fcntl qw/ O_RDONLY /;
 use POSIX qw/ ceil /;
 use Types::Standard qw/ ArrayRef Int /;
 
-our $VERSION = '0.0601';
+use constant page_size => POSIX::sysconf POSIX::_SC_PAGESIZE;
+
+our $VERSION = '0.0602';
 
 # ABSTRACT: simple access to Linux /proc/../statm
 
@@ -21,20 +23,6 @@ has pid => (
     );
 
 
-my $PageSize;
-
-has page_size => (
-    is      => 'lazy',
-    isa     => Int,
-    default => sub {
-        $PageSize //= `getconf PAGE_SIZE`
-            or die "Unable to run getconf PAGE_SIZE: $!";
-        $PageSize += 0;
-        },
-    init_arg => undef,
-    );
-
-
 has statm => (
     is       => 'lazy',
     isa      => ArrayRef[Int],
@@ -98,7 +86,7 @@ foreach my $attr (keys %stats) {
             is       => 'lazy',
             isa      => Int,
             default  => sub { my $self = shift;
-                              ceil($self->$attr * $self->page_size / $alts{$alt});
+                              ceil($self->$attr * page_size / $alts{$alt});
                               },
             init_arg => undef,
             clearer  => "_refresh_${attr}_${alt}",
@@ -137,7 +125,7 @@ Linux::Statm::Tiny - simple access to Linux /proc/../statm
 
 =head1 VERSION
 
-version 0.0601
+version 0.0602
 
 =head1 SYNOPSIS
 
@@ -250,7 +238,7 @@ Robert Rothenberg <rrwo@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Adrian Lai Karen Etheridge Mohammad S Anwar
+=for stopwords Adrian Lai James Raspass Karen Etheridge Mohammad S Anwar
 
 =over 4
 
@@ -260,6 +248,10 @@ Adrian Lai <aidy@cpan.org>
 
 =item *
 
+James Raspass <jraspass@gmail.com>
+
+=item *
+
 Karen Etheridge <ether@cpan.org>
 
 =item *
